@@ -27,7 +27,7 @@ class Pusher(object):
         return self._channels[key]
 
     def _make_channel(self, name):
-        self._channels[name] = Channel(name, self)
+        self._channels[name] = channel_type(name, self)
         return self._channels[name]
 
 class Channel(object):
@@ -38,10 +38,7 @@ class Channel(object):
 
     def trigger(self, event, data={}):
         json_data = json.dumps(data)
-        http = httplib.HTTPConnection(self.pusher.host, self.pusher.port)
-        signed_path = '%s?%s' % (self.path, self.signed_query(event, json_data))
-        http.request('POST', signed_path, json_data)
-        status = http.getresponse().status
+        status = self.send_request(self.signed_query(event, json_data), json_data)
         if status == 202:
             return True
         elif status == 401:
@@ -63,8 +60,28 @@ class Channel(object):
         hash_str = hasher.hexdigest()
         return "auth_key=%s&auth_timestamp=%s&auth_version=1.0&body_md5=%s&name=%s" % (self.pusher.key, int(time.time()), hash_str, event)
 
+    def send_request(self, query_string, data_string):
+        signed_path = '%s?%s' % (self.path, query_string)
+        http = httplib.HTTPConnection(self.pusher.host, self.pusher.port)
+        http.request('POST', signed_path, data_string)
+        return http.getresponse().status
+
+class GoogleAppEngineChannel(Channel):
+    def send_request(self, query_string, data_string):
+        from google.appengine.api import urlfetch
+        absolute_url = 'http://%s/%s?%s' % (self.pusher.host, self.path, query_string)
+        response = urlfetch.fetch(
+            url=absolute_url,
+            payload=data_string,
+            method=urlfetch.POST,
+            headers={'Content-Type': 'application/json'}
+        )
+        return response.status_code
+
 class AuthenticationError(Exception):
     pass
 
 class NotFoundError(Exception):
-    pass
\ No newline at end of file
+    pass
+
+channel_type = Channel
